==> simpype-0.0.1.dev2.tar.gz: simpype-0.0.1.dev2/setup.py <==
# Always prefer setuptools over distutils
from setuptools import setup
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))
# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='simpype',
    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version='0.0.1.dev2',
    description='SimPype is a simulation framework based on Simpy that relies on the concepts of resource and pipe.',
    long_description=long_description,
    # The project's main homepage.
    url='https://github.com/Mallets/SimPype/',
    # Author details
    author='Luca Cominardi',
    author_email='luca.cominardi@gmail.com',
    # Choose your license
    license='GPLv3+ License',
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',
		'Environment :: Console',
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering',
        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.4',
    ],
	python_requires='>=3.4',
    keywords='simulation queue pipe simpy',
	packages=['simpype', 'simpype.model'],
    install_requires=['simpy>=3.0.10'],
)

==> simpype-1.0.0.tar.gz: simpype-1.0.0/setup.py <==
# Always prefer setuptools over distutils
from setuptools import setup
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))
# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='simpype',
    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version='1.0.0',
    description='SimPype is a simulation framework based on Simpy that relies on the concepts of resource and pipe.',
    long_description=long_description,
    long_description_content_type='text/x-rst',
    # The project's main homepage.
    url='https://github.com/Mallets/SimPype/',
    # Author details
    author='Luca Cominardi',
    author_email='luca.cominardi@gmail.com',
    # Choose your license
    license='GPLv3+ License',
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',
		'Environment :: Console',
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering',
        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
	python_requires='>=3.3',
    keywords='simulation queue pipe simpy',
	packages=['simpype', 'simpype.model'],
    install_requires=['simpy>=3.0.10'],
)
